@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,13 +8,6 @@
 #
 # Thanks for using Enthought open source!
 
-try:
-    from envisage.version import version as __version__
-except ImportError:
-    # If we get here, we're using a source tree that hasn't been created via
-    # the setup script.
-    __version__ = "unknown"
-
 # Per logging best practices, add a NullHandler to the root 'envisage'
 # logger.
 import logging
