@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A plugin manager composed of other plugin managers! """
 
@@ -13,8 +14,15 @@
 import logging
 
 # Enthought library imports.
-from traits.api import Event, HasTraits, Instance, List, provides
-from traits.api import on_trait_change
+from traits.api import (
+    Event,
+    HasTraits,
+    Instance,
+    List,
+    observe,
+    on_trait_change,
+    provides,
+)
 
 # Local imports.
 from .i_application import IApplication
@@ -23,19 +31,18 @@ from .i_plugin_manager import IPluginManager
 from .plugin_event import PluginEvent
 from .plugin_manager import PluginManager
 
-
 # Logging.
 logger = logging.getLogger(__name__)
 
 
 @provides(IPluginManager)
 class CompositePluginManager(HasTraits):
-    """ A plugin manager composed of other plugin managers!
+    """A plugin manager composed of other plugin managers!
 
     e.g::
 
         plugin_manager = CompositePluginManager(
-             plugin_mangers = [
+             plugin_managers = [
                  EggBasketPluginManager(...),
                  PackagePluginManager(...),
              ]
@@ -43,7 +50,7 @@ class CompositePluginManager(HasTraits):
 
     """
 
-    #### 'IPluginManager' protocol #############################################
+    #### 'IPluginManager' protocol ############################################
 
     #### Events ####
 
@@ -53,16 +60,17 @@ class CompositePluginManager(HasTraits):
     # Fired when a plugin has been removed from the manager.
     plugin_removed = Event(PluginEvent)
 
-    #### 'CompositePluginManager' protocol #####################################
+    #### 'CompositePluginManager' protocol ####################################
 
     # The application that the plugin manager is part of.
     application = Instance(IApplication)
-    def _application_changed(self, trait_name, old, new):
+
+    @observe("application")
+    def _update_application(self, event):
+        new = event.new
         for plugin_manager in self.plugin_managers:
             plugin_manager.application = new
 
-        return
-
     # The plugin managers that make up this plugin manager!
     #
     # This is currently a list of 'PluginManager's as opposed to, the more
@@ -70,26 +78,28 @@ class CompositePluginManager(HasTraits):
     # have an 'application' trait. Should we move 'application' up to
     # 'IPluginManager'?
     plugin_managers = List(PluginManager)
-    @on_trait_change('plugin_managers[]')
-    def _update_application(self, obj, trait_named, removed, added):
+
+    @on_trait_change("plugin_managers[]")
+    def _update_application_on_plugins(self, obj, trait_named, removed, added):
         for plugin_manager in removed:
             plugin_manager.application = self.application
 
         for plugin_manager in added:
             plugin_manager.application = self.application
 
-    @on_trait_change('plugin_managers:plugin_added')
+    @on_trait_change("plugin_managers:plugin_added")
     def _plugin_added(self, obj, trait_name, old, new):
         self.plugin_added = new
 
-    @on_trait_change('plugin_managers:plugin_removed')
+    @on_trait_change("plugin_managers:plugin_removed")
     def _plugin_removed(self, obj, trait_name, old, new):
         self.plugin_removed = new
 
-    #### Private protocol ######################################################
+    #### Private protocol #####################################################
 
     # The plugins that the manager manages!
     _plugins = List(IPlugin)
+
     def __plugins_default(self):
         plugins = []
         for plugin_manager in self.plugin_managers:
@@ -101,7 +111,7 @@ class CompositePluginManager(HasTraits):
     #### 'object' protocol ####################################################
 
     def __iter__(self):
-        """ Return an iterator over the manager's plugins. """
+        """Return an iterator over the manager's plugins."""
 
         plugins = []
         for plugin_manager in self.plugin_managers:
@@ -110,15 +120,15 @@ class CompositePluginManager(HasTraits):
 
         return iter(plugins)
 
-    #### 'IPluginManager' protocol #############################################
+    #### 'IPluginManager' protocol ############################################
 
     def add_plugin(self, plugin):
-        """ Add a plugin to the manager. """
+        """Add a plugin to the manager."""
 
         raise NotImplementedError
 
     def get_plugin(self, plugin_id):
-        """ Return the plugin with the specified Id. """
+        """Return the plugin with the specified Id."""
 
         for plugin in self:
             if plugin_id == plugin.id:
@@ -130,34 +140,30 @@ class CompositePluginManager(HasTraits):
         return plugin
 
     def remove_plugin(self, plugin):
-        """ Remove a plugin from the manager. """
+        """Remove a plugin from the manager."""
 
         raise NotImplementedError
 
     def start(self):
-        """ Start the plugin manager. """
+        """Start the plugin manager."""
 
         for plugin in self:
             self.start_plugin(plugin)
 
-        return
-
     def start_plugin(self, plugin=None, plugin_id=None):
-        """ Start the specified plugin. """
+        """Start the specified plugin."""
 
         plugin = plugin or self.get_plugin(plugin_id)
         if plugin is not None:
-            logger.debug('plugin %s starting', plugin.id)
+            logger.debug("plugin %s starting", plugin.id)
             plugin.activator.start_plugin(plugin)
-            logger.debug('plugin %s started', plugin.id)
+            logger.debug("plugin %s started", plugin.id)
 
         else:
-            raise SystemError('no such plugin %s' % plugin_id)
-
-        return
+            raise ValueError("no such plugin %s" % plugin_id)
 
     def stop(self):
-        """ Stop the plugin manager. """
+        """Stop the plugin manager."""
 
         # We stop the plugins in the reverse order that they were started.
         stop_order = list(iter(self))
@@ -166,20 +172,14 @@ class CompositePluginManager(HasTraits):
         for plugin in stop_order:
             self.stop_plugin(plugin)
 
-        return
-
     def stop_plugin(self, plugin=None, plugin_id=None):
-        """ Stop the specified plugin. """
+        """Stop the specified plugin."""
 
         plugin = plugin or self.get_plugin(plugin_id)
         if plugin is not None:
-            logger.debug('plugin %s stopping', plugin.id)
+            logger.debug("plugin %s stopping", plugin.id)
             plugin.activator.stop_plugin(plugin)
-            logger.debug('plugin %s stopped', plugin.id)
+            logger.debug("plugin %s stopped", plugin.id)
 
         else:
-            raise SystemError('no such plugin %s' % plugin_id)
-
-        return
-
-#### EOF ######################################################################
+            raise ValueError("no such plugin %s" % plugin_id)
