@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,6 +13,7 @@
 # Standard library imports.
 import logging
 import re
+import warnings
 
 # 3rd party imports.
 import pkg_resources
@@ -24,13 +25,12 @@ from traits.api import Instance, List, Str
 from .egg_utils import get_entry_points_in_egg_order
 from .plugin_manager import PluginManager
 
-
 # Logging.
 logger = logging.getLogger(__name__)
 
 
 class EggPluginManager(PluginManager):
-    """ A plugin manager that gets its plugins from Eggs.
+    """A plugin manager that gets its plugins from Eggs.
 
     To declare a plugin (or plugins) in your egg use an entry point in your
     'setup.py' file, e.g.
@@ -46,6 +46,18 @@ class EggPluginManager(PluginManager):
 
     """
 
+    def __init__(self, **traits):
+        warnings.warn(
+            (
+                "The EggPluginManager is deprecated. The recommended "
+                "approach is to install plugin-containing packages into "
+                "site-packages and advertise the plugins via entry points. "
+            ),
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(**traits)
+
     # Entry point Id.
     PLUGINS = "envisage.plugins"
 
@@ -54,7 +66,7 @@ class EggPluginManager(PluginManager):
     # The working set that contains the eggs that contain the plugins that
     # live in the house that Jack built ;^) By default we use the global
     # working set.
-    working_set = Instance(pkg_resources.WorkingSet, pkg_resources.working_set)
+    working_set = Instance(pkg_resources.WorkingSet)
 
     # An optional list of the Ids of the plugins that are to be excluded by
     # the manager.
@@ -76,7 +88,7 @@ class EggPluginManager(PluginManager):
     ###########################################################################
 
     def __plugins_default(self):
-        """ Trait initializer. """
+        """Trait initializer."""
 
         plugins = []
         for ep in get_entry_points_in_egg_order(
@@ -90,12 +102,17 @@ class EggPluginManager(PluginManager):
 
         return plugins
 
+    def _working_set_default(self):
+        """Trait initializer."""
+
+        return pkg_resources.working_set
+
     ###########################################################################
     # Private interface.
     ###########################################################################
 
     def _create_plugin_from_ep(self, ep):
-        """ Create a plugin from an extension point. """
+        """Create a plugin from an extension point."""
 
         klass = ep.load()
         plugin = klass(application=self.application)
@@ -111,7 +128,7 @@ class EggPluginManager(PluginManager):
         return plugin
 
     def _is_excluded(self, plugin_id):
-        """ Return True if the plugin Id is excluded.
+        """Return True if the plugin Id is excluded.
 
         If no 'exclude' patterns are specified then this method returns False
         for all plugin Ids.
@@ -128,7 +145,7 @@ class EggPluginManager(PluginManager):
         return False
 
     def _is_included(self, plugin_id):
-        """ Return True if the plugin Id is included.
+        """Return True if the plugin Id is included.
 
         If no 'include' patterns are specified then this method returns True
         for all plugin Ids.
