@@ -1,13 +1,24 @@
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ A simple example of a GUIApplication which wraps a TraitsUI """
 
-from traits.api import HasTraits, Str, Int, Enum, Instance, on_trait_change
+from traits.api import Enum, HasTraits, Instance, Int, on_trait_change, Str
+from traitsui.api import Item, OKCancelButtons, View
+
 from envisage.api import Plugin
 from envisage.ui.gui_application import GUIApplication
-from traitsui.api import View, Item, OKCancelButtons
 
 
 class Person(HasTraits):
-    """ A typical traits model object """
+    """A typical traits model object"""
 
     name = Str("John Doe")
 
@@ -16,12 +27,15 @@ class Person(HasTraits):
     gender = Enum("Male", "Female")
 
     view = View(
-        Item("name"), Item("age"), Item("gender"), buttons=OKCancelButtons,
+        Item("name"),
+        Item("age"),
+        Item("gender"),
+        buttons=OKCancelButtons,
     )
 
 
 class PersonViewPlugin(Plugin):
-    """ The 'Person View' plugin.
+    """The 'Person View' plugin.
 
     This plugin waits for the application to start, and then creates a traits
     UI.
@@ -32,7 +46,7 @@ class PersonViewPlugin(Plugin):
 
     @on_trait_change("application:application_initialized")
     def on_application_start(self):
-        """ Start the UI. """
+        """Start the UI."""
 
         person = Person()
 
@@ -42,7 +56,6 @@ class PersonViewPlugin(Plugin):
 
 # Application entry point.
 if __name__ == "__main__":
-
     # Create the application.
     application = GUIApplication(
         id="person_view", plugins=[PersonViewPlugin()]
