@@ -1,28 +1,37 @@
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # System library imports.
 import numpy as np
+
+# Local imports.
+from attractors.model.i_plottable_2d import IPlottable2d
 from scipy import array, zeros
 
 # Enthought library imports.
 from traits.api import (
     Array,
+    cached_property,
     Float,
     HasTraits,
     Int,
     Property,
-    Str,
-    cached_property,
     provides,
+    Str,
 )
 from traitsui.api import Item, View
 
-# Local imports.
-from attractors.model.i_plottable_2d import IPlottable2d
-
 
 @provides(IPlottable2d)
 class Henon(HasTraits):
-    """ The model object for the Henon map.
-    """
+    """The model object for the Henon map."""
 
     #### 'Henon' interface ####################################################
 
@@ -65,7 +74,7 @@ class Henon(HasTraits):
         points = zeros((self.steps, 2))
         for i in range(self.steps):
             x, y = points[i] = point
-            point = array([y + 1 - self.a * x ** 2, self.b * x])
+            point = array([y + 1 - self.a * x**2, self.b * x])
         return points
 
     @cached_property
