@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,15 +8,13 @@
 #
 # Thanks for using Enthought open source!
 import os
-import pkg_resources
 import unittest
 
 from envisage.examples._etsdemo_info import info
 
 
 class TestETSDemoInfo(unittest.TestCase):
-
     def test_info(self):
         # input to info is currently just a placeholder
         response = info({})
-        self.assertTrue(os.path.exists(response['root']))
+        self.assertTrue(os.path.exists(response["root"]))
