@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -10,9 +10,6 @@
 """ A binding between a trait on an object and an extension point. """
 
 
-# Standard library imports.
-import weakref
-
 # Enthought library imports.
 from traits.api import Any, HasTraits, Instance, Str, Undefined
 
@@ -21,13 +18,12 @@ from .i_extension_registry import IExtensionRegistry
 
 
 class ExtensionPointBinding(HasTraits):
-    """ A binding between a trait on an object and an extension point. """
+    """A binding between a trait on an object and an extension point."""
 
     #### 'ExtensionPointBinding' *CLASS* interface ############################
 
-    # We keep a reference to each binding alive until its associated object
-    # is garbage collected.
-    _bindings = weakref.WeakKeyDictionary()
+    # Global dictionary used to keep ExtensionPointBinding objects alive.
+    _bindings = {}
 
     #### 'ExtensionPointBinding' interface ####################################
 
@@ -55,7 +51,7 @@ class ExtensionPointBinding(HasTraits):
     ###########################################################################
 
     def __init__(self, **traits):
-        """ Constructor. """
+        """Constructor."""
 
         super().__init__(**traits)
 
@@ -63,26 +59,7 @@ class ExtensionPointBinding(HasTraits):
         self._set_trait(notify=False)
 
         # Wire-up the trait change and extension point handlers.
-        self._initialize()
-
-        # We keep a reference to each binding alive until its associated
-        # object is garbage collected.
-        bindings = ExtensionPointBinding._bindings.setdefault(self.obj, [])
-        bindings.append(self)
-
-    ###########################################################################
-    # 'ExtensionPointBinding' interface.
-    ###########################################################################
-
-    #### Trait initializers ###################################################
-
-    def _extension_registry_default(self):
-        """ Trait initializer. """
-
-        # fixme: Sneaky global!!!!!
-        from .extension_point import ExtensionPoint
-
-        return ExtensionPoint.extension_registry
+        self._bind()
 
     ###########################################################################
     # Private interface.
@@ -91,13 +68,13 @@ class ExtensionPointBinding(HasTraits):
     #### Trait change handlers ################################################
 
     def _on_trait_changed(self, obj, trait_name, old, new):
-        """ Dynamic trait change handler. """
+        """Dynamic trait change handler."""
 
         if not self._event_handled:
             self._set_extensions(new)
 
     def _on_trait_items_changed(self, obj, trait_name, old, event):
-        """ Dynamic trait change handler. """
+        """Dynamic trait change handler."""
 
         if not self._event_handled:
             self._set_extensions(getattr(obj, self.trait_name))
@@ -105,7 +82,7 @@ class ExtensionPointBinding(HasTraits):
     #### Other observer pattern listeners #####################################
 
     def _extension_point_listener(self, extension_registry, event):
-        """ Listener called when an extension point is changed. """
+        """Listener called when an extension point is changed."""
 
         self._event_handled = True
         if event.index is not None:
@@ -117,8 +94,8 @@ class ExtensionPointBinding(HasTraits):
 
     #### Methods ##############################################################
 
-    def _initialize(self):
-        """ Wire-up trait change handlers etc. """
+    def _bind(self):
+        """Wire-up trait change handlers etc."""
 
         # Listen for the object's trait being changed.
         self.obj.on_trait_change(self._on_trait_changed, self.trait_name)
@@ -132,8 +109,25 @@ class ExtensionPointBinding(HasTraits):
             self._extension_point_listener, self.extension_point_id
         )
 
+    def _unbind(self):
+        """Undo the effects of _bind"""
+
+        self.extension_registry.remove_extension_point_listener(
+            self._extension_point_listener, self.extension_point_id
+        )
+
+        self.obj.on_trait_change(
+            self._on_trait_items_changed,
+            self.trait_name + "_items",
+            remove=True,
+        )
+
+        self.obj.on_trait_change(
+            self._on_trait_changed, self.trait_name, remove=True
+        )
+
     def _set_trait(self, notify):
-        """ Set the object's trait to the value of the extension point. """
+        """Set the object's trait to the value of the extension point."""
 
         value = self.extension_registry.get_extensions(self.extension_point_id)
         traits = {self.trait_name: value}
@@ -141,7 +135,7 @@ class ExtensionPointBinding(HasTraits):
         self.obj.trait_set(trait_change_notify=notify, **traits)
 
     def _update_trait(self, event):
-        """ Update the object's trait to the value of the extension point. """
+        """Update the object's trait to the value of the extension point."""
 
         self._set_trait(notify=False)
 
@@ -150,7 +144,7 @@ class ExtensionPointBinding(HasTraits):
         )
 
     def _set_extensions(self, extensions):
-        """ Set the extensions to an extension point. """
+        """Set the extensions to an extension point."""
 
         self.extension_registry.set_extensions(
             self.extension_point_id, extensions
@@ -159,29 +153,87 @@ class ExtensionPointBinding(HasTraits):
 
 # Factory function for creating bindings.
 def bind_extension_point(
-    obj, trait_name, extension_point_id, extension_registry=None
+    obj, trait_name, extension_point_id, extension_registry
 ):
-    """ Create a binding to an extension point. """
+    """Create a binding to an extension point.
 
-    # This may seem a bit wierd, but we manually build up a dictionary of
-    # the traits that need to be set at the time the 'ExtensionPointBinding'
-    # instance is created.
-    #
-    # This is because we only want to set the 'extension_registry' trait iff
-    # one is explicitly specified. If we passed it in with the default argument
-    # value of 'None' then it counts as 'setting' the trait which prevents
-    # the binding instance from defaulting to the appropriate registry.
-    # Also, if we try to set the 'extension_registry' trait *after*
-    # construction time then it is too late as the binding initialization is
-    # done in the constructor (we could of course split that out, which may be
-    # the 'right' way to do it ;^).
-    traits = {
-        "obj": obj,
-        "trait_name": trait_name,
-        "extension_point_id": extension_point_id,
-    }
+    The returned ExtensionPointBinding object is also stored in a (private)
+    global dictionary, so that users aren't required to keep a reference to it.
+    That global dictionary entry can be removed with a matching call to
+    unbind_extension_point.
 
-    if extension_registry is not None:
-        traits["extension_registry"] = extension_registry
+    Parameters
+    ----------
+    obj : HasTraits
+        The HasTraits object that we're binding to
+    trait_name : str
+        The name of the trait on obj to bind to.
+    extension_point_id : str
+        The id of the extension point.
+    extension_registry : IExtensionRegistry
+        The extension registry that the extension point is registered to.
 
-    return ExtensionPointBinding(**traits)
+    Returns
+    -------
+    ExtensionPointBinding
+        An object that manages the binding.
+    """
+
+    binding = ExtensionPointBinding(
+        obj=obj,
+        trait_name=trait_name,
+        extension_point_id=extension_point_id,
+        extension_registry=extension_registry,
+    )
+
+    # Keep a reference to each binding in the ExtensionPointBinding._bindings
+    # global dictionary. Without this, the binding would become inactive
+    # if the caller didn't keep a reference.
+    bindings = ExtensionPointBinding._bindings.setdefault(obj, [])
+    bindings.append(binding)
+    return binding
+
+
+def unbind_extension_point(
+    obj, trait_name, extension_point_id, extension_registry
+):
+    """
+    Remove an extension point binding.
+
+    Changes to extension point contributions will no longer affect the target
+    trait. Also removes the matching ExtensionPointBinding object from the
+    global dictionary.
+
+    Parameters
+    ----------
+    obj : HasTraits
+        The HasTraits object that we're binding to
+    trait_name : str
+        The name of the trait on obj to bind to.
+    extension_point_id : str
+        The id of the extension point.
+    extension_registry : IExtensionRegistry
+        The extension registry that the extension point is registered to.
+    """
+    # Find the corresponding binding in the global dict.
+    bindings = ExtensionPointBinding._bindings
+
+    # Find the matching ExtensionPointBinding object. Search in reverse order,
+    # since that's most likely to give the right binding quickly under the
+    # normal first-in-last-out pattern for nested setup and teardown.
+    index, binding = next(
+        (index, binding)
+        for index, binding in reversed(list(enumerate(bindings[obj])))
+        if binding.trait_name == trait_name
+        if binding.extension_point_id == extension_point_id
+        if binding.extension_registry == extension_registry
+    )
+
+    # Remove the binding from the global dict, and remove the dict entry
+    # altogether if it's now empty.
+    bindings[obj].pop(index)
+    if not bindings[obj]:
+        bindings.pop(obj)
+
+    # Undo the binding
+    binding._unbind()
