@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,20 +15,16 @@ from .i_extension_registry import IExtensionRegistry
 
 
 class IProviderExtensionRegistry(IExtensionRegistry):
-    """ The provider extension registry interface. """
+    """The provider extension registry interface."""
 
     def add_provider(self, provider):
-        """ Add an extension provider.
-
-        """
+        """Add an extension provider."""
 
     def get_providers(self):
-        """ Return all of the providers in the registry.
-
-        """
+        """Return all of the providers in the registry."""
 
     def remove_provider(self, provider):
-        """ Remove an extension provider.
+        """Remove an extension provider.
 
         Raise a 'ValueError' if the provider is not in the registry.
 
