@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,24 +15,16 @@ from traits.api import Interface
 
 
 class IPythonShell(Interface):
-    """ A simple interface for the Python shell. """
+    """A simple interface for the Python shell."""
 
     def bind(self, name, value):
-        """ Binds a name to a value in the interpreter's namespace.
-
-        """
+        """Binds a name to a value in the interpreter's namespace."""
 
     def execute_command(self, command, hidden=True):
-        """ Execute a command in the interpreter.
-
-        """
+        """Execute a command in the interpreter."""
 
     def execute_file(self, path, hidden=True):
-        """ Execute a file in the interpreter.
-
-        """
+        """Execute a file in the interpreter."""
 
     def lookup(self, name):
-        """ Returns the value bound to a name in the interpreter's namespace.
-
-        """
+        """Returns the value bound to a name in the interpreter's namespace."""
