@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,8 +12,7 @@ from envisage.ui.action.api import Action, ActionSet, Group
 
 
 class TextEditorActionSet(ActionSet):
-    """ The default action set for the Text Editor plugin.
-    """
+    """The default action set for the Text Editor plugin."""
 
     groups = [
         Group(id="TextFileGroup", path="MenuBar/File", before="ExitGroup")
