@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,8 +13,8 @@
 
 # Enthought library imports.
 from traits.api import List
-from envisage.api import Plugin
 
+from envisage.api import Plugin
 
 # The plugin's globally unique identifier (also used as the prefix for all
 # identifiers defined in this module).
@@ -22,8 +22,7 @@ ID = "envisage.plugins.text_editor"
 
 
 class TextEditorPlugin(Plugin):
-    """ Text Editor plugin for the Workbench UI.
-    """
+    """Text Editor plugin for the Workbench UI."""
 
     name = "Text Editor plugin"
 
