@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,15 +14,14 @@
 import logging
 
 # Enthought library imports.
-from traits.api import TraitType
-
+from traits.api import TraitError, TraitType
 
 # Logging.
 logger = logging.getLogger(__name__)
 
 
 class Service(TraitType):
-    """ A trait type used to access services.
+    """A trait type used to access services.
 
     Note that this is a trait *type* and hence does *NOT* have traits itself
     (i.e. it does *not* inherit from 'HasTraits').
@@ -36,7 +35,7 @@ class Service(TraitType):
     def __init__(
         self, protocol=None, query="", minimize="", maximize="", **metadata
     ):
-        """ Constructor. """
+        """Constructor."""
 
         super().__init__(**metadata)
 
@@ -53,7 +52,7 @@ class Service(TraitType):
         self._maximize = maximize
 
     def __repr__(self):
-        """ String representation of a Service object """
+        """String representation of a Service object"""
         return "Service(protocol={!r})".format(self._protocol)
 
     ###########################################################################
@@ -61,7 +60,7 @@ class Service(TraitType):
     ###########################################################################
 
     def get(self, obj, trait_name):
-        """ Trait type getter. """
+        """Trait type getter."""
 
         service_registry = self._get_service_registry(obj)
 
@@ -72,16 +71,16 @@ class Service(TraitType):
         return obj
 
     def set(self, obj, name, value):
-        """ Trait type setter. """
+        """Trait type setter."""
 
-        raise SystemError("Service traits cannot be set")
+        raise TraitError("Service traits cannot be set")
 
     ###########################################################################
     # Private interface.
     ###########################################################################
 
     def _get_service_registry(self, obj):
-        """ Return the service registry in effect for an object. """
+        """Return the service registry in effect for an object."""
 
         service_registry = getattr(obj, "service_registry", None)
         if service_registry is None:
