@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,40 +15,27 @@ import os
 import shutil
 import unittest
 
+from traits.api import Bool, Int, List
+
 # Enthought library imports.
 from traits.etsconfig.api import ETSConfig
-from envisage.api import Application, ExtensionPoint
-from envisage.api import Plugin, PluginManager
-from traits.api import Bool, Int, List
+
+from envisage.api import ExtensionPoint, Plugin, PluginManager
+from envisage.tests.ets_config_patcher import ETSConfigPatcher
 
 # Local imports.
 from envisage.tests.event_tracker import EventTracker
-from envisage.tests.ets_config_patcher import ETSConfigPatcher
-
-
-def listener(obj, trait_name, old, new):
-    """ A useful trait change handler for testing! """
-
-    listener.obj = obj
-    listener.trait_name = trait_name
-    listener.old = old
-    listener.new = new
+from envisage.tests.support import PluginA, PluginB, PluginC, SimpleApplication
 
 
 def vetoer(event):
-    """ A function that will veto an event. """
+    """An observer that will veto an event."""
 
-    event.veto = True
-
-
-class TestApplication(Application):
-    """ The type of application used in the tests. """
-
-    id = "test"
+    event.new.veto = True
 
 
 class SimplePlugin(Plugin):
-    """ A simple plugin. """
+    """A simple plugin."""
 
     #### 'SimplePlugin' interface #############################################
 
@@ -60,65 +47,44 @@ class SimplePlugin(Plugin):
     ###########################################################################
 
     def start(self):
-        """ Start the plugin. """
+        """Start the plugin."""
 
         self.started = True
         self.stopped = False
 
     def stop(self):
-        """ Stop the plugin. """
+        """Stop the plugin."""
 
         self.started = False
         self.stopped = True
 
 
 class BadPlugin(Plugin):
-    """ A plugin that just causes trouble ;^). """
+    """A plugin that just causes trouble ;^)."""
 
     ###########################################################################
     # 'IPlugin' interface.
     ###########################################################################
 
     def start(self):
-        """ Start the plugin. """
+        """Start the plugin."""
 
         raise 1 / 0
 
     def stop(self):
-        """ Stop the plugin. """
+        """Stop the plugin."""
 
         raise 1 / 0
 
 
-class PluginA(Plugin):
-    """ A plugin that offers an extension point. """
-
-    id = "A"
-    x = ExtensionPoint(List, id="a.x")
-
-
-class PluginB(Plugin):
-    """ A plugin that contributes to an extension point. """
-
-    id = "B"
-    x = List(Int, [1, 2, 3], contributes_to="a.x")
-
-
-class PluginC(Plugin):
-    """ Another plugin that contributes to an extension point! """
-
-    id = "C"
-    x = List(Int, [98, 99, 100], contributes_to="a.x")
-
-
 # PluginD and PluginE each contribute to the other's extension points, but both
 # expect to be started before contributions are made.
 # xref: enthought/envisage#417
 
 
 class PluginD(Plugin):
-    """ Plugin that expects to be started before contributing to
-    extension points. """
+    """Plugin that expects to be started before contributing to
+    extension points."""
 
     id = "D"
     x = ExtensionPoint(List, id="d.x")
@@ -138,8 +104,8 @@ class PluginD(Plugin):
 
 
 class PluginE(Plugin):
-    """ Another plugin that expects to be started before contributing to
-    extension points. """
+    """Another plugin that expects to be started before contributing to
+    extension points."""
 
     id = "E"
     x = ExtensionPoint(List, id="e.x")
@@ -159,25 +125,19 @@ class PluginE(Plugin):
 
 
 class ApplicationTestCase(unittest.TestCase):
-    """ Tests for applications and plugins. """
+    """Tests for applications and plugins."""
 
     def setUp(self):
-        """ Prepares the test fixture before each test method is called. """
-
-        # Make sure that the listener contents get cleand up before each test.
-        listener.obj = None
-        listener.trait_name = None
-        listener.old = None
-        listener.new = None
+        """Prepares the test fixture before each test method is called."""
 
         ets_config_patcher = ETSConfigPatcher()
         ets_config_patcher.start()
         self.addCleanup(ets_config_patcher.stop)
 
     def test_home(self):
-        """ home """
+        """home"""
 
-        application = TestApplication()
+        application = SimpleApplication()
 
         # Make sure we get the right default value.
         self.assertEqual(ETSConfig.application_home, application.home)
@@ -186,7 +146,7 @@ class ApplicationTestCase(unittest.TestCase):
         shutil.rmtree(application.home)
 
         # Create a new application.
-        application = TestApplication()
+        application = SimpleApplication()
 
         # Make sure the directory got created.
         self.assertTrue(os.path.exists(application.home))
@@ -195,9 +155,9 @@ class ApplicationTestCase(unittest.TestCase):
         shutil.rmtree(application.home)
 
     def test_no_plugins(self):
-        """ no plugins """
+        """no plugins"""
 
-        application = TestApplication()
+        application = SimpleApplication()
 
         tracker = EventTracker(
             subscriptions=[
@@ -221,12 +181,12 @@ class ApplicationTestCase(unittest.TestCase):
         )
 
     def test_veto_starting(self):
-        """ veto starting """
+        """veto starting"""
 
-        application = TestApplication()
+        application = SimpleApplication()
 
         # This listener will veto the 'starting' event.
-        application.on_trait_change(vetoer, "starting")
+        application.observe(vetoer, "starting")
 
         tracker = EventTracker(
             subscriptions=[
@@ -243,12 +203,12 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertTrue("started" not in tracker.event_names)
 
     def test_veto_stopping(self):
-        """ veto stopping """
+        """veto stopping"""
 
-        application = TestApplication()
+        application = SimpleApplication()
 
         # This listener will veto the 'stopping' event.
-        application.on_trait_change(vetoer, "stopping")
+        application.observe(vetoer, "stopping")
 
         tracker = EventTracker(
             subscriptions=[
@@ -270,11 +230,11 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertTrue("stopped" not in tracker.event_names)
 
     def test_start_and_stop_errors(self):
-        """ start and stop errors """
+        """start and stop errors"""
 
         simple_plugin = SimplePlugin()
         bad_plugin = BadPlugin()
-        application = TestApplication(plugins=[simple_plugin, bad_plugin])
+        application = SimpleApplication(plugins=[simple_plugin, bad_plugin])
 
         # Try to start the application - the bad plugin should barf.
         with self.assertRaises(ZeroDivisionError):
@@ -285,21 +245,21 @@ class ApplicationTestCase(unittest.TestCase):
             application.stop()
 
         # Try to start a non-existent plugin.
-        with self.assertRaises(SystemError):
+        with self.assertRaises(ValueError):
             application.start_plugin(plugin_id="bogus")
 
         # Try to stop a non-existent plugin.
-        with self.assertRaises(SystemError):
+        with self.assertRaises(ValueError):
             application.stop_plugin(plugin_id="bogus")
 
     def test_extension_point(self):
-        """ extension point """
+        """extension point"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # Make sure we can get the contributions via the application.
@@ -318,7 +278,7 @@ class ApplicationTestCase(unittest.TestCase):
         # Given
         d = PluginD()
         e = PluginE()
-        application = TestApplication(plugins=[d, e])
+        application = SimpleApplication(plugins=[d, e])
 
         # When
         application.start()
@@ -334,18 +294,18 @@ class ApplicationTestCase(unittest.TestCase):
         )
 
     def test_add_extension_point_listener(self):
-        """ add extension point listener """
+        """add extension point listener"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
         # Start off with just two of the plugins.
-        application = TestApplication(plugins=[a, b])
+        application = SimpleApplication(plugins=[a, b])
         application.start()
 
         def listener(extension_registry, event):
-            """ An extension point listener. """
+            """An extension point listener."""
 
             listener.extension_point_id = event.extension_point_id
             listener.added = event.added
@@ -368,18 +328,18 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertEqual([98, 99, 100], listener.added)
 
     def test_remove_extension_point_listener(self):
-        """ remove extension point listener """
+        """remove extension point listener"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
         # Start off with just one of the plugins.
-        application = TestApplication(plugins=[a])
+        application = SimpleApplication(plugins=[a])
         application.start()
 
         def listener(extension_registry, event):
-            """ An extension point listener. """
+            """An extension point listener."""
 
             listener.extension_point_id = event.extension_point_id
             listener.added = event.added
@@ -411,14 +371,14 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertEqual(None, listener.extension_point_id)
 
     def test_add_plugin(self):
-        """ add plugin """
+        """add plugin"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
         # Start off with just two of the plugins.
-        application = TestApplication(plugins=[a, b])
+        application = SimpleApplication(plugins=[a, b])
         application.start()
 
         # Make sure we can get the contributions via the application.
@@ -445,14 +405,14 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertEqual([1, 2, 3, 98, 99, 100], extensions)
 
     def test_get_plugin(self):
-        """ get plugin """
+        """get plugin"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
         # Start off with just two of the plugins.
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # Make sure we can get the plugins.
@@ -464,13 +424,13 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertEqual(None, application.get_plugin("BOGUS"))
 
     def test_remove_plugin(self):
-        """ remove plugin """
+        """remove plugin"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # Make sure we can get the contributions via the application.
@@ -497,14 +457,14 @@ class ApplicationTestCase(unittest.TestCase):
         self.assertEqual([98, 99, 100], extensions)
 
     def test_set_plugin_manager_at_contruction_time(self):
-        """ set plugin manager at construction time"""
+        """set plugin manager at construction time"""
 
         a = PluginA()
         b = PluginB()
         c = PluginC()
 
         # Start off with just two of the plugins.
-        application = TestApplication(
+        application = SimpleApplication(
             plugin_manager=PluginManager(plugins=[a, b, c])
         )
         application.start()
