@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,26 +15,21 @@ import unittest
 # Major package imports.
 from pkg_resources import resource_filename
 
-# Enthought library imports.
-from envisage.api import Application, CorePlugin, Plugin
-from envisage.api import ServiceOffer
 from traits.api import HasTraits, Interface, List, on_trait_change, Str
 
+# Enthought library imports.
+from envisage.api import CorePlugin, Plugin, ServiceOffer
+from envisage.tests.support import SimpleApplication
+
 # This module's package.
 PKG = "envisage.tests"
 
 
-class TestApplication(Application):
-    """ The type of application used in the tests. """
-
-    id = "core.plugin.test"
-
-
 class CorePluginTestCase(unittest.TestCase):
-    """ Tests for the core plugin. """
+    """Tests for the core plugin."""
 
     def test_service_offers(self):
-        """ service offers """
+        """service offers"""
 
         class IMyService(Interface):
             pass
@@ -45,7 +40,7 @@ class CorePluginTestCase(unittest.TestCase):
             service_offers = List(contributes_to="envisage.service_offers")
 
             def _service_offers_default(self):
-                """ Trait initializer. """
+                """Trait initializer."""
 
                 service_offers = [
                     ServiceOffer(
@@ -56,14 +51,14 @@ class CorePluginTestCase(unittest.TestCase):
                 return service_offers
 
             def _my_service_factory(self, **properties):
-                """ Service factory. """
+                """Service factory."""
 
                 return 42
 
         core = CorePlugin()
         a = PluginA()
 
-        application = TestApplication(plugins=[core, a])
+        application = SimpleApplication(plugins=[core, a])
         application.start()
 
         # Lookup the service.
@@ -76,7 +71,7 @@ class CorePluginTestCase(unittest.TestCase):
         self.assertEqual(None, application.get_service(IMyService))
 
     def test_dynamically_added_service_offer(self):
-        """ dynamically added service offer """
+        """dynamically added service offer"""
 
         class IMyService(Interface):
             pass
@@ -87,7 +82,7 @@ class CorePluginTestCase(unittest.TestCase):
             service_offers = List(contributes_to="envisage.service_offers")
 
             def _service_offers_default(self):
-                """ Trait initializer. """
+                """Trait initializer."""
 
                 service_offers = [
                     ServiceOffer(
@@ -98,7 +93,7 @@ class CorePluginTestCase(unittest.TestCase):
                 return service_offers
 
             def _my_service_factory(self, **properties):
-                """ Service factory. """
+                """Service factory."""
 
                 return 42
 
@@ -106,7 +101,7 @@ class CorePluginTestCase(unittest.TestCase):
         a = PluginA()
 
         # Start off with just the core plugin.
-        application = TestApplication(plugins=[core])
+        application = SimpleApplication(plugins=[core])
         application.start()
 
         # Make sure the service does not exist!
@@ -130,35 +125,35 @@ class CorePluginTestCase(unittest.TestCase):
         self.assertEqual(42, service)
 
     def test_preferences(self):
-        """ preferences """
+        """preferences"""
 
         class PluginA(Plugin):
             id = "A"
             preferences = List(contributes_to="envisage.preferences")
 
             def _preferences_default(self):
-                """ Trait initializer. """
+                """Trait initializer."""
 
                 return ["file://" + resource_filename(PKG, "preferences.ini")]
 
         core = CorePlugin()
         a = PluginA()
 
-        application = TestApplication(plugins=[core, a])
+        application = SimpleApplication(plugins=[core, a])
         application.run()
 
         # Make sure we can get one of the preferences.
         self.assertEqual("42", application.preferences.get("enthought.test.x"))
 
     def test_dynamically_added_preferences(self):
-        """ dynamically added preferences """
+        """dynamically added preferences"""
 
         class PluginA(Plugin):
             id = "A"
             preferences = List(contributes_to="envisage.preferences")
 
             def _preferences_default(self):
-                """ Trait initializer. """
+                """Trait initializer."""
 
                 return ["file://" + resource_filename(PKG, "preferences.ini")]
 
@@ -166,7 +161,7 @@ class CorePluginTestCase(unittest.TestCase):
         a = PluginA()
 
         # Start with just the core plugin.
-        application = TestApplication(plugins=[core])
+        application = SimpleApplication(plugins=[core])
         application.start()
 
         # Now add a plugin that contains a preference.
@@ -177,7 +172,7 @@ class CorePluginTestCase(unittest.TestCase):
 
     # regression test for enthought/envisage#251
     def test_unregister_service_offer(self):
-        """ Unregister a service that is contributed to the
+        """Unregister a service that is contributed to the
         "envisage.service_offers" extension point while the application is
         running.
         """
@@ -195,7 +190,6 @@ class CorePluginTestCase(unittest.TestCase):
             service_offers = List(contributes_to=SERVICE_OFFERS)
 
             def _service_offers_default(self):
-
                 a_service_offer = ServiceOffer(
                     protocol=IJunk,
                     factory=self._create_junk_service,
@@ -204,7 +198,7 @@ class CorePluginTestCase(unittest.TestCase):
                 return [a_service_offer]
 
             def _create_junk_service(self):
-                """ Factory method for the 'Junk' service. """
+                """Factory method for the 'Junk' service."""
 
                 return Junk()
 
@@ -213,7 +207,7 @@ class CorePluginTestCase(unittest.TestCase):
                 # only 1 service is registered so it has service_id of 1
                 self.application.unregister_service(1)
 
-        application = TestApplication(
+        application = SimpleApplication(
             plugins=[CorePlugin(), PluginA()],
         )
 
@@ -221,9 +215,9 @@ class CorePluginTestCase(unittest.TestCase):
         application.run()
 
     def test_unregister_service(self):
-        """ Unregister a service which was registered on the application
+        """Unregister a service which was registered on the application
         directly, not through the CorePlugin's extension point. CorePlugin
-        should not do anything to interfere. """
+        should not do anything to interfere."""
 
         class IJunk(Interface):
             trash = Str()
@@ -233,7 +227,7 @@ class CorePluginTestCase(unittest.TestCase):
 
         some_junk = Junk()
 
-        application = TestApplication(
+        application = SimpleApplication(
             plugins=[CorePlugin()],
         )
 
