@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,78 +9,63 @@
 # Thanks for using Enthought open source!
 """ Tests for the 'Egg Basket' plugin manager. """
 
+import contextlib
 import glob
-from os.path import basename, join
+import os
 import shutil
-import sys
 import tempfile
 import unittest
+from os.path import basename, join
 
 import pkg_resources
 
 from envisage.egg_basket_plugin_manager import EggBasketPluginManager
-from envisage.tests.test_egg_based import build_egg
+from envisage.tests.support import (
+    BAD_PLUGIN_PACKAGES,
+    build_egg,
+    PLUGIN_PACKAGES,
+    restore_pkg_resources_working_set,
+    restore_sys_modules,
+    restore_sys_path,
+    temporary_directory,
+)
 
 
 class EggBasketPluginManagerTestCase(unittest.TestCase):
-    """ Tests for the 'Egg Basket' plugin manager. """
-
-    #### 'unittest.TestCase' protocol #########################################
+    """Tests for the 'Egg Basket' plugin manager."""
 
     @classmethod
     def setUpClass(cls):
-        """
-        Create eggs for testing purposes.
-        """
-        cls.eggs_dir = tempfile.mkdtemp()
-        cls.bad_eggs_dir = tempfile.mkdtemp()
+        cls.egg_cleanup_stack = contextlib.ExitStack()
+        cls.eggs_dir = os.fspath(
+            cls.egg_cleanup_stack.enter_context(temporary_directory())
+        )
+        cls.bad_eggs_dir = os.fspath(
+            cls.egg_cleanup_stack.enter_context(temporary_directory())
+        )
 
-        eggs_root_dir = pkg_resources.resource_filename(
-            "envisage.tests", "eggs")
-        for egg_name in ["acme.bar", "acme.baz", "acme.foo"]:
-            build_egg(
-                egg_dir=join(eggs_root_dir, egg_name),
-                dist_dir=cls.eggs_dir,
-            )
-
-        bad_eggs_root_dir = pkg_resources.resource_filename(
-            "envisage.tests", "bad_eggs")
-        for egg_name in ["acme.bad"]:
-            build_egg(
-                egg_dir=join(bad_eggs_root_dir, egg_name),
-                dist_dir=cls.bad_eggs_dir,
-            )
+        # Build eggs
+        for package in PLUGIN_PACKAGES:
+            build_egg(package_dir=package, dist_dir=cls.eggs_dir)
+        for package in BAD_PLUGIN_PACKAGES:
+            build_egg(package_dir=package, dist_dir=cls.bad_eggs_dir)
 
     @classmethod
     def tearDownClass(cls):
-        """
-        Delete created eggs.
-        """
-        shutil.rmtree(cls.bad_eggs_dir)
-        shutil.rmtree(cls.eggs_dir)
+        cls.egg_cleanup_stack.close()
 
     def setUp(self):
-        """ Prepares the test fixture before each test method is called. """
-
-        # Some tests cause sys.path to be modified. Capture the original
-        # contents so that we can restore sys.path later.
-        self._original_sys_path_contents = sys.path[:]
-
-    def tearDown(self):
-        """ Called immediately after each test method has been called. """
-
-        # Undo any sys.path modifications
-        sys.path[:] = self._original_sys_path_contents
-
-        # `envisage.egg_utils.get_entry_points_in_egg_order` modifies the
-        # global working set.
-        pkg_resources.working_set = pkg_resources.WorkingSet()
-
-    #### Tests ################################################################
+        with contextlib.ExitStack() as cleanup_stack:
+            cleanup_stack.enter_context(restore_sys_path())
+            cleanup_stack.enter_context(restore_sys_modules())
+            cleanup_stack.enter_context(restore_pkg_resources_working_set())
+            self.addCleanup(cleanup_stack.pop_all().close)
 
     def test_find_plugins_in_eggs_on_the_plugin_path(self):
-
-        plugin_manager = EggBasketPluginManager(plugin_path=[self.eggs_dir])
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.eggs_dir]
+            )
 
         ids = [plugin.id for plugin in plugin_manager]
         self.assertEqual(len(ids), 3)
@@ -89,14 +74,14 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self.assertIn("acme.baz", ids)
 
     def test_only_find_plugins_whose_ids_are_in_the_include_list(self):
-
         # Note that the items in the list use the 'fnmatch' syntax for matching
         # plugins Ids.
         include = ["acme.foo", "acme.bar"]
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.eggs_dir], include=include
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.eggs_dir], include=include
+            )
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.foo", "acme.bar"]
@@ -106,14 +91,14 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_only_find_plugins_matching_a_wildcard_in_the_include_list(self):
-
         # Note that the items in the list use the 'fnmatch' syntax for matching
         # plugins Ids.
         include = ["acme.b*"]
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.eggs_dir], include=include
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.eggs_dir], include=include
+            )
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.bar", "acme.baz"]
@@ -123,14 +108,14 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_ignore_plugins_whose_ids_are_in_the_exclude_list(self):
-
         # Note that the items in the list use the 'fnmatch' syntax for matching
         # plugins Ids.
         exclude = ["acme.foo", "acme.baz"]
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.eggs_dir], exclude=exclude
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.eggs_dir], exclude=exclude
+            )
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.bar"]
@@ -140,14 +125,14 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_ignore_plugins_matching_a_wildcard_in_the_exclude_list(self):
-
         # Note that the items in the list use the 'fnmatch' syntax for matching
         # plugins Ids.
         exclude = ["acme.b*"]
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.eggs_dir], exclude=exclude
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.eggs_dir], exclude=exclude
+            )
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.foo"]
@@ -157,7 +142,8 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_reflect_changes_to_the_plugin_path(self):
-        plugin_manager = EggBasketPluginManager()
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager()
         ids = [plugin.id for plugin in plugin_manager]
         self.assertEqual(len(ids), 0)
 
@@ -173,9 +159,10 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self.assertEqual(len(ids), 0)
 
     def test_ignore_broken_plugins_raises_exceptions_by_default(self):
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.bad_eggs_dir, self.eggs_dir],
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.bad_eggs_dir, self.eggs_dir],
+            )
         with self.assertRaises(ImportError):
             list(plugin_manager)
 
@@ -187,10 +174,11 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
             data["entry_point"] = ep
             data["exc"] = exc
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[self.bad_eggs_dir, self.eggs_dir],
-            on_broken_plugin=on_broken_plugin,
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[self.bad_eggs_dir, self.eggs_dir],
+                on_broken_plugin=on_broken_plugin,
+            )
 
         ids = [plugin.id for plugin in plugin_manager]
         self.assertEqual(len(ids), 3)
@@ -205,22 +193,23 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
 
     def test_ignore_broken_distributions_raises_exceptions_by_default(self):
         # Make sure that the distributions from eggs are already in the working
-        # set. This includes acme.foo, with version 0.1a1.
+        # set. This includes acme-foo, with version 0.1a1.
         for dist in pkg_resources.find_distributions(self.eggs_dir):
             pkg_resources.working_set.add(dist)
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[
-                # Attempt to add acme.foo, with conflicting version 0.1a11
-                self._create_broken_distribution_eggdir("acme.foo*.egg"),
-            ],
-        )
-        with self.assertRaises(SystemError):
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[
+                    # Attempt to add acme-foo, with conflicting version 0.1a11
+                    self._create_broken_distribution_eggdir("acme_foo*.egg"),
+                ],
+            )
+        with self.assertRaises(RuntimeError):
             iter(plugin_manager)
 
     def test_ignore_broken_distributions_loads_good_distributions(self):
         # Make sure that the distributions from eggs are already in the working
-        # set. This includes acme.foo, with version 0.1a1.
+        # set. This includes acme-foo, with version 0.1a1.
         for dist in pkg_resources.find_distributions(self.eggs_dir):
             pkg_resources.working_set.add(dist)
 
@@ -231,13 +220,14 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
             data["distribution"] = dist
             data["exc"] = exc
 
-        plugin_manager = EggBasketPluginManager(
-            plugin_path=[
-                self.eggs_dir,
-                self._create_broken_distribution_eggdir("acme.foo*.egg"),
-            ],
-            on_broken_distribution=on_broken_distribution,
-        )
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggBasketPluginManager(
+                plugin_path=[
+                    self.eggs_dir,
+                    self._create_broken_distribution_eggdir("acme_foo*.egg"),
+                ],
+                on_broken_distribution=on_broken_distribution,
+            )
 
         ids = [plugin.id for plugin in plugin_manager]
         self.assertEqual(len(ids), 3)
@@ -246,15 +236,15 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
         self.assertIn("acme.baz", ids)
 
         self.assertEqual(data["count"], 1)
-        self.assertEqual(data["distribution"].project_name, "acme.foo")
+        self.assertEqual(data["distribution"].project_name, "acme-foo")
         exc = data["exc"]
         self.assertTrue(isinstance(exc, pkg_resources.VersionConflict))
 
     #### Private protocol #####################################################
 
     def _test_start_and_stop(self, plugin_manager, expected):
-        """ Make sure the plugin manager starts and stops the expected plugins.
-
+        """
+        Make sure the plugin manager starts and stops the expected plugins.
         """
 
         # Make sure the plugin manager found only the required plugins.
@@ -281,12 +271,13 @@ class EggBasketPluginManagerTestCase(unittest.TestCase):
             self.assertEqual(True, plugin.stopped)
 
     def _create_broken_distribution_eggdir(self, egg_pat, replacement=None):
-        """ Copy a good egg to a different version egg name in a new temp dir
+        """Copy a good egg to a different version egg name in a new temp dir
         and return the new directory.
 
         Parameters
         ----------
-        egg_pat: a glob pattern for the egg in `self.egg_dir` eg 'foo.bar*.egg'
+        egg_pat: a glob pattern for the egg in `self.eggs_dir`
+           for example 'foo.bar*.egg'
         replacement: a string replacement for the version part of egg name.
             If None, '1' is appended to the original version.
 
