@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -7,35 +7,68 @@
 # is also available online at http://www.enthought.com/licenses/BSD.txt
 #
 # Thanks for using Enthought open source!
+
 """ Tests for the Egg plugin manager. """
 
-# 3rd party imports.
+import contextlib
+import os
+import unittest
+
 import pkg_resources
+from pkg_resources import Environment, working_set
 
-# Enthought library imports.
 from envisage.api import EggPluginManager
-
-# Local imports.
-from .test_egg_based import EggBasedTestCase
+from envisage.tests.support import (
+    build_egg,
+    PLUGIN_PACKAGES,
+    restore_pkg_resources_working_set,
+    restore_sys_modules,
+    restore_sys_path,
+    temporary_directory,
+)
 
 
-class EggPluginManagerTestCase(EggBasedTestCase):
-    """ Tests for the Egg plugin manager. """
+class EggPluginManagerTestCase(unittest.TestCase):
+    """Tests for the Egg plugin manager."""
 
-    ###########################################################################
-    # Tests.
-    ###########################################################################
+    @classmethod
+    def setUpClass(cls):
+        cls.egg_cleanup_stack = contextlib.ExitStack()
+        cls.egg_dir = os.fspath(
+            cls.egg_cleanup_stack.enter_context(temporary_directory())
+        )
+
+        # Build eggs
+        for package in PLUGIN_PACKAGES:
+            build_egg(package_dir=package, dist_dir=cls.egg_dir)
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.egg_cleanup_stack.close()
+
+    def setUp(self):
+        with contextlib.ExitStack() as cleanup_stack:
+            cleanup_stack.enter_context(restore_sys_path())
+            cleanup_stack.enter_context(restore_sys_modules())
+            cleanup_stack.enter_context(restore_pkg_resources_working_set())
+            self.addCleanup(cleanup_stack.pop_all().close)
+
+        # Make eggs importable
+        # 'find_plugins' identifies those distributions that *could* be added
+        # to the working set without version conflicts or missing requirements.
+        environment = Environment([os.fspath(self.egg_dir)])
+        distributions, errors = working_set.find_plugins(environment)
+        if len(distributions) == 0 or len(errors) > 0:
+            raise RuntimeError(f"Cannot find eggs {errors}")
+        for distribution in distributions:
+            working_set.add(distribution)
 
-    # fixme: Depending how many eggs are on sys.path, this test may take too
-    # long to be part of the TDD cycle.
     def test_no_include_or_exclude(self):
-        """ no include or exclude """
-
-        # Add all of the eggs in the egg basket.
-        self._add_eggs_on_path([self.egg_dir])
+        """no include or exclude"""
 
         # Make sure that the plugin manager only includes those plugins.
-        plugin_manager = EggPluginManager()
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggPluginManager()
 
         # We don't know how many plugins we will actually get - it depends on
         # what eggs are on sys.path! What we *do* know however is the the 3
@@ -47,9 +80,7 @@ class EggPluginManagerTestCase(EggBasedTestCase):
         self.assertTrue("acme.baz" in ids)
 
     def test_include_specific(self):
-        """ include specific """
-        # Add all of the eggs in the egg basket.
-        self._add_eggs_on_path([self.egg_dir])
+        """include specific"""
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.foo", "acme.bar"]
@@ -60,17 +91,15 @@ class EggPluginManagerTestCase(EggBasedTestCase):
         include = [r"acme\.foo", r"acme\.bar"]
 
         # Make sure that the plugin manager only includes those plugins.
-        plugin_manager = EggPluginManager(include=include)
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggPluginManager(include=include)
 
         # Make sure the plugin manager found only the required plugins and that
         # it starts and stops them correctly..
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_include_multiple(self):
-        """ include multiple """
-
-        # Add all of the eggs in the egg basket.
-        self._add_eggs_on_path([self.egg_dir])
+        """include multiple"""
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.foo", "acme.bar", "acme.baz"]
@@ -81,17 +110,15 @@ class EggPluginManagerTestCase(EggBasedTestCase):
         include = ["acme.*"]
 
         # Make sure that the plugin manager only includes those plugins.
-        plugin_manager = EggPluginManager(include=include)
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggPluginManager(include=include)
 
         # Make sure the plugin manager found only the required plugins and that
         # it starts and stops them correctly..
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_exclude_specific(self):
-        """ exclude specific """
-
-        # Add all of the eggs in the egg basket.
-        self._add_eggs_on_path([self.egg_dir])
+        """exclude specific"""
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.bar"]
@@ -105,17 +132,15 @@ class EggPluginManagerTestCase(EggBasedTestCase):
         exclude = [r"acme\.foo", r"acme\.baz"]
 
         # Make sure that the plugin manager excludes the specified plugins.
-        plugin_manager = EggPluginManager(include=include, exclude=exclude)
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggPluginManager(include=include, exclude=exclude)
 
         # Make sure the plugin manager found only the required plugins and that
         # it starts and stops them correctly..
         self._test_start_and_stop(plugin_manager, expected)
 
     def test_exclude_multiple(self):
-        """ exclude multiple """
-
-        # Add all of the eggs in the egg basket.
-        self._add_eggs_on_path([self.egg_dir])
+        """exclude multiple"""
 
         # The Ids of the plugins that we expect the plugin manager to find.
         expected = ["acme.foo"]
@@ -129,7 +154,8 @@ class EggPluginManagerTestCase(EggBasedTestCase):
         exclude = [r"acme\.b.*"]
 
         # Make sure that the plugin manager excludes the specified plugins.
-        plugin_manager = EggPluginManager(include=include, exclude=exclude)
+        with self.assertWarns(DeprecationWarning):
+            plugin_manager = EggPluginManager(include=include, exclude=exclude)
 
         # Make sure the plugin manager found only the required plugins and that
         # it starts and stops them correctly..
@@ -142,12 +168,11 @@ class EggPluginManagerTestCase(EggBasedTestCase):
             # Create fresh working set for this test, to make sure that the
             # plugin manager picks up the *current* value of
             # pkg_resources.working_set.
-            pkg_resources.working_set = pkg_resources.WorkingSet()
-            plugin_manager = EggPluginManager()
-            self.assertEqual(
-                plugin_manager.working_set,
-                pkg_resources.working_set,
-            )
+            fresh_working_set = pkg_resources.WorkingSet()
+            pkg_resources.working_set = fresh_working_set
+            with self.assertWarns(DeprecationWarning):
+                plugin_manager = EggPluginManager()
+            self.assertEqual(plugin_manager.working_set, fresh_working_set)
         finally:
             pkg_resources.working_set = original_working_set
 
@@ -156,8 +181,8 @@ class EggPluginManagerTestCase(EggBasedTestCase):
     ###########################################################################
 
     def _test_start_and_stop(self, plugin_manager, expected):
-        """ Make sure the plugin manager starts and stops the expected plugins.
-
+        """
+        Make sure the plugin manager starts and stops the expected plugins.
         """
 
         # Make sure the plugin manager found only the required plugins.
