@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,65 +14,54 @@ import unittest
 
 # Local imports.
 from envisage.api import ExtensionPointChangedEvent
-from envisage.tests.test_application import (
-    PluginA,
-    PluginB,
-    PluginC,
-    TestApplication,
-    listener,
-)
+from envisage.tests.support import PluginA, PluginB, PluginC, SimpleApplication
 
 
 class ExtensionPointChangedTestCase(unittest.TestCase):
-    """ Tests for the events fired when extension points are changed. """
-
-    def setUp(self):
-        """ Prepares the test fixture before each test method is called. """
-
-        # Make sure that the listener contents get cleand up before each test.
-        listener.obj = None
-        listener.trait_name = None
-        listener.old = None
-        listener.new = None
+    """Tests for the events fired when extension points are changed."""
 
     def test_set_extension_point(self):
-        """ set extension point """
+        """set extension point"""
 
         a = PluginA()
 
-        application = TestApplication(plugins=[a])
+        application = SimpleApplication(plugins=[a])
         application.start()
 
         # Try to set the extension point.
-        with self.assertRaises(SystemError):
+        with self.assertRaises(TypeError):
             setattr(a, "x", [1, 2, 3])
 
     def test_mutate_extension_point_no_events(self):
-        """ Mutation will not emit change event for name_items """
+        """Mutation will not emit change event for name_items"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # when
         a.x.append(42)
 
         # then
-        self.assertIsNone(listener.obj)
+        self.assertEqual(events, [])
 
     def test_append(self):
-        """ append """
+        """append"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # fixme: If the extension point has not been accessed then the
@@ -99,21 +88,25 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([4], listener.new.added)
-        self.assertEqual([], listener.new.removed)
-        self.assertEqual(3, listener.new.index)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([4], event.new.added)
+        self.assertEqual([], event.new.removed)
+        self.assertEqual(3, event.new.index)
 
     def test_remove(self):
-        """ remove """
+        """remove"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # fixme: If the extension point has not been accessed then the
@@ -140,21 +133,25 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([], listener.new.added)
-        self.assertEqual([3], listener.new.removed)
-        self.assertEqual(2, listener.new.index)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([], event.new.added)
+        self.assertEqual([3], event.new.removed)
+        self.assertEqual(2, event.new.index)
 
     def test_assign_empty_list(self):
-        """ assign empty list """
+        """assign empty list"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # fixme: If the extension point has not been accessed then the
@@ -181,22 +178,26 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([], listener.new.added)
-        self.assertEqual([1, 2, 3], listener.new.removed)
-        self.assertEqual(0, listener.new.index.start)
-        self.assertEqual(3, listener.new.index.stop)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([], event.new.added)
+        self.assertEqual([1, 2, 3], event.new.removed)
+        self.assertEqual(0, event.new.index.start)
+        self.assertEqual(3, event.new.index.stop)
 
     def test_assign_empty_list_no_event(self):
-        """ assign empty list no event """
+        """assign empty list no event"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # Assign an empty list to one of the plugin's contributions.
@@ -218,17 +219,19 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # We shouldn't get a trait event here because we haven't accessed the
         # extension point yet!
-        self.assertEqual(None, listener.obj)
+        self.assertEqual(events, [])
 
     def test_assign_non_empty_list(self):
-        """ assign non-empty list """
+        """assign non-empty list"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # fixme: If the extension point has not been accessed then the
@@ -258,34 +261,36 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([2, 4, 6, 8], listener.new.added)
-        self.assertEqual([1, 2, 3], listener.new.removed)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([2, 4, 6, 8], event.new.added)
+        self.assertEqual([1, 2, 3], event.new.removed)
 
         # The removed entry should match what the old values say
-        self.assertEqual(
-            listener.new.removed, source_values[listener.new.index]
-        )
+        self.assertEqual(event.new.removed, source_values[event.new.index])
 
         # If we use the index and apply the changes to the old list, we should
         # recover the new list
-        source_values[listener.new.index] = listener.new.added
+        source_values[event.new.index] = event.new.added
         self.assertEqual(source_values, application.get_extensions("a.x"))
 
-        self.assertEqual(0, listener.new.index.start)
-        self.assertEqual(3, listener.new.index.stop)
+        self.assertEqual(0, event.new.index.start)
+        self.assertEqual(3, event.new.index.stop)
 
     def test_add_plugin(self):
-        """ add plugin """
+        """add plugin"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
         # Start off with just two of the plugins.
-        application = TestApplication(plugins=[a, b])
+        application = SimpleApplication(plugins=[a, b])
         application.start()
 
         # Make sure we can get the contributions via the application.
@@ -321,21 +326,25 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([98, 99, 100], listener.new.added)
-        self.assertEqual([], listener.new.removed)
-        self.assertEqual(3, listener.new.index)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([98, 99, 100], event.new.added)
+        self.assertEqual([], event.new.removed)
+        self.assertEqual(3, event.new.index)
 
     def test_remove_plugin(self):
-        """ remove plugin """
+        """remove plugin"""
+
+        events = []
 
         a = PluginA()
-        a.on_trait_change(listener, "x_items")
+        a.observe(events.append, "x_items")
         b = PluginB()
         c = PluginC()
 
-        application = TestApplication(plugins=[a, b, c])
+        application = SimpleApplication(plugins=[a, b, c])
         application.start()
 
         # Make sure we can get the contributions via the application.
@@ -371,17 +380,22 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
 
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
-        self.assertEqual(a, listener.obj)
-        self.assertEqual("x_items", listener.trait_name)
-        self.assertEqual([], listener.new.added)
-        self.assertEqual([1, 2, 3], listener.new.removed)
-        self.assertEqual(0, listener.new.index)
+        self.assertEqual(len(events), 1)
+        event = events[0]
+        self.assertEqual(a, event.object)
+        self.assertEqual("x_items", event.name)
+        self.assertEqual([], event.new.added)
+        self.assertEqual([1, 2, 3], event.new.removed)
+        self.assertEqual(0, event.new.index)
 
     def test_extension_point_change_event_str_representation(self):
-        """ test string representation of the ExtensionPointChangedEvent class
         """
-        desired_repr = ("ExtensionPointChangedEvent(extension_point_id={}, "
-                        "index=0, removed=[], added=[])")
+        test string representation of the ExtensionPointChangedEvent class
+        """
+        desired_repr = (
+            "ExtensionPointChangedEvent(extension_point_id={}, "
+            "index=0, removed=[], added=[])"
+        )
         ext_pt_changed_evt = ExtensionPointChangedEvent(extension_point_id=1)
         self.assertEqual(desired_repr.format(1), str(ext_pt_changed_evt))
         self.assertEqual(desired_repr.format(1), repr(ext_pt_changed_evt))
