@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,43 +12,48 @@
 # Standard library imports.
 import unittest
 
-# Enthought library imports.
-from envisage.api import ExtensionPoint, ExtensionProvider
-from envisage.api import ProviderExtensionRegistry
 from traits.api import Int, List
 
+# Enthought library imports.
+from envisage.api import (
+    ExtensionPoint,
+    ExtensionProvider,
+    ProviderExtensionRegistry,
+)
+
 # Local imports.
 from envisage.tests.test_extension_registry_mixin import (
-    ExtensionRegistryTestMixin
+    ExtensionRegistryTestMixin,
 )
 
 
 class ProviderExtensionRegistryTestCase(
-        ExtensionRegistryTestMixin, unittest.TestCase):
-    """ Tests for the provider extension registry. """
+    ExtensionRegistryTestMixin, unittest.TestCase
+):
+    """Tests for the provider extension registry."""
 
     def setUp(self):
-        """ Prepares the test fixture before each test method is called. """
+        """Prepares the test fixture before each test method is called."""
 
         self.registry = ProviderExtensionRegistry()
 
     def test_providers(self):
-        """ providers """
+        """providers"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """Return the extension points offered by the provider."""
 
                 return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -60,11 +65,11 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
         class ProviderB(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -76,7 +81,7 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
         class ProviderC(ExtensionProvider):
-            """ An empty provider! """
+            """An empty provider!"""
 
         # Add the providers to the registry.
         registry.add_provider(ProviderA())
@@ -94,24 +99,24 @@ class ProviderExtensionRegistryTestCase(
         self.assertEqual("x", extension_points[0].id)
 
     def test_provider_extensions_changed(self):
-        """ provider extensions changed """
+        """provider extensions changed"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             x = List(Int)
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """Return the extension points offered by the provider."""
 
                 return [ExtensionPoint(List, "my.ep")]
 
             def get_extensions(self, extension_point_id):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point_id == "my.ep":
@@ -123,27 +128,27 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
             def _x_changed(self, old, new):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "my.ep", new, old, slice(0, len(old))
                 )
 
             def _x_items_changed(self, event):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "my.ep", event.added, event.removed, event.index
                 )
 
         class ProviderB(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             x = List(Int)
 
             def get_extensions(self, extension_point_id):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point_id == "my.ep":
@@ -155,14 +160,14 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
             def _x_changed(self, old, new):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "my.ep", new, old, slice(0, len(old))
                 )
 
             def _x_items_changed(self, event):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "my.ep", event.added, event.removed, event.index
@@ -181,7 +186,7 @@ class ProviderExtensionRegistryTestCase(
 
         # Add an extension listener to the registry.
         def listener(registry, event):
-            """ A useful trait change handler for testing! """
+            """A useful trait change handler for testing!"""
 
             listener.registry = registry
             listener.extension_point = event.extension_point_id
@@ -235,22 +240,22 @@ class ProviderExtensionRegistryTestCase(
         self.assertEqual([42, 43, 1, 2], extensions)
 
     def test_add_provider(self):
-        """ add provider """
+        """add provider"""
 
         registry = self.registry
 
         # A provider.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """Return the extension points offered by the provider."""
 
                 return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -262,7 +267,7 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
             def _x_items_changed(self, event):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "x", event.added, event.removed, event.index
@@ -278,7 +283,7 @@ class ProviderExtensionRegistryTestCase(
 
         # Add an extension listener to the registry.
         def listener(registry, event):
-            """ A useful trait change handler for testing! """
+            """A useful trait change handler for testing!"""
 
             listener.registry = registry
             listener.extension_point = event.extension_point_id
@@ -290,11 +295,11 @@ class ProviderExtensionRegistryTestCase(
 
         # Add a new provider.
         class ProviderB(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -320,16 +325,16 @@ class ProviderExtensionRegistryTestCase(
         self.assertTrue(44 in extensions)
 
     def test_get_providers(self):
-        """ get providers """
+        """get providers"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
         class ProviderB(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
         a = ProviderA()
         b = ProviderB()
@@ -342,22 +347,22 @@ class ProviderExtensionRegistryTestCase(
         self.assertEqual([a, b], registry.get_providers())
 
     def test_remove_provider(self):
-        """ remove provider """
+        """remove provider"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """Return the extension points offered by the provider."""
 
                 return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -369,18 +374,18 @@ class ProviderExtensionRegistryTestCase(
                 return extensions
 
             def _x_items_changed(self, event):
-                """ Static trait change handler. """
+                """Static trait change handler."""
 
                 self._fire_extension_point_changed(
                     "x", event.added, event.removed, event.index
                 )
 
         class ProviderB(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
@@ -406,7 +411,7 @@ class ProviderExtensionRegistryTestCase(
 
         # Add an extension listener to the registry.
         def listener(registry, event):
-            """ A useful trait change handler for testing! """
+            """A useful trait change handler for testing!"""
 
             listener.registry = registry
             listener.extension_point = event.extension_point_id
@@ -444,22 +449,22 @@ class ProviderExtensionRegistryTestCase(
         self.assertEqual([42], listener.removed)
 
     def test_remove_provider_with_no_contributions(self):
-        """ remove provider with no contributions """
+        """remove provider with no contributions"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """Return the extension points offered by the provider."""
 
                 return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 return []
@@ -474,7 +479,7 @@ class ProviderExtensionRegistryTestCase(
 
         # Add an extension listener to the registry.
         def listener(registry, event):
-            """ A useful trait change handler for testing! """
+            """A useful trait change handler for testing!"""
 
             listener.registry = registry
             listener.extension_point = event.extension_point_id
@@ -498,13 +503,13 @@ class ProviderExtensionRegistryTestCase(
         self.assertEqual(None, getattr(listener, "registry", None))
 
     def test_remove_non_existent_provider(self):
-        """ remove provider """
+        """remove provider"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             pass
 
@@ -515,7 +520,7 @@ class ProviderExtensionRegistryTestCase(
             registry.remove_provider(a)
 
     def test_set_extensions(self):
-        """ set extensions """
+        """set extensions"""
 
         registry = self.registry
 
@@ -523,26 +528,28 @@ class ProviderExtensionRegistryTestCase(
         registry.add_extension_point(self.create_extension_point("my.ep"))
 
         # Set some extensions.
-        with self.assertRaises(SystemError):
+        with self.assertRaises(TypeError):
             registry.set_extensions("my.ep", [1, 2, 3])
 
     def test_remove_non_empty_extension_point(self):
-        """ remove non-empty extension point """
+        """remove non-empty extension point"""
 
         registry = self.registry
 
         # Some providers.
         class ProviderA(ExtensionProvider):
-            """ An extension provider. """
+            """An extension provider."""
 
             def get_extension_points(self):
-                """ Return the extension points offered by the provider. """
+                """
+                Return the extension points offered by the provider.
+                """
 
                 return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
-                """ Return the provider's contributions to an extension point.
-
+                """
+                Return the provider's contributions to an extension point.
                 """
 
                 if extension_point == "x":
