@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,21 +13,17 @@
 import unittest
 
 # Enthought library imports.
-from envisage.api import Application, Plugin, Service
-from traits.api import HasTraits, Instance
+from traits.api import HasTraits, Instance, TraitError
 
-
-class TestApplication(Application):
-    """ The type of application used in the tests. """
-
-    id = "test"
+from envisage.api import Plugin, Service
+from envisage.tests.support import SimpleApplication
 
 
 class ServiceTestCase(unittest.TestCase):
-    """ Tests for the 'Service' trait type. """
+    """Tests for the 'Service' trait type."""
 
     def test_service_trait_type(self):
-        """ service trait type"""
+        """service trait type"""
 
         class Foo(HasTraits):
             pass
@@ -43,7 +39,7 @@ class ServiceTestCase(unittest.TestCase):
         a = PluginA()
         b = PluginB()
 
-        application = TestApplication(plugins=[a, b])
+        application = SimpleApplication(plugins=[a, b])
         application.start()
 
         # Make sure the services were registered.
@@ -56,11 +52,11 @@ class ServiceTestCase(unittest.TestCase):
         self.assertEqual(None, b.foo)
 
         # You can't set service traits!
-        with self.assertRaises(SystemError):
+        with self.assertRaises(TraitError):
             setattr(b, "foo", "bogus")
 
     def test_service_trait_type_with_no_service_registry(self):
-        """ service trait type with no service registry """
+        """service trait type with no service registry"""
 
         class Foo(HasTraits):
             pass
@@ -75,7 +71,7 @@ class ServiceTestCase(unittest.TestCase):
             getattr(b, "foo")
 
     def test_service_str_representation(self):
-        """ test the string representation of the service """
+        """test the string representation of the service"""
 
         class Foo(HasTraits):
             pass
