@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,8 +12,7 @@ from traits.api import HasTraits, Str
 
 
 class PreferencesCategory(HasTraits):
-    """ The description for a container of PreferencesPanes.
-    """
+    """The description for a container of PreferencesPanes."""
 
     # The globally unique identifier for the category.
     id = Str
@@ -32,6 +31,5 @@ class PreferencesCategory(HasTraits):
     ###########################################################################
 
     def _name_default(self):
-        """ By default, use the ID for the name.
-        """
+        """By default, use the ID for the name."""
         return self.id
