@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,15 +15,13 @@ from .task_window import TaskWindow
 
 
 class TaskWindowEvent(HasTraits):
-    """ A task window lifecycle event.
-    """
+    """A task window lifecycle event."""
 
     #: The window that the event occurred on.
     window = Instance(TaskWindow)
 
 
 class VetoableTaskWindowEvent(TaskWindowEvent, Vetoable):
-    """ A vetoable task window lifecycle event.
-    """
+    """A vetoable task window lifecycle event."""
 
     pass
