@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -37,11 +37,11 @@ to run tests in that environment.  You can remove the environment with::
 
 If you make changes you will either need to remove and re-install the
 environment or manually update the environment using ``edm``, as
-the install performs a ``python setup.py install`` rather than a ``develop``,
+the install performs a ``pip install`` rather than a ``pip install -e``,
 so changes in your code will not be automatically mirrored in the test
 environment.  You can update with a command like::
 
-    edm run --environment ... -- python setup.py install
+    edm run --environment ... -- pip install .
 
 You can run all three tasks at once with::
 
@@ -85,37 +85,43 @@ from tempfile import mkdtemp
 import click
 
 # Python runtime versions supported by this tool.
-available_runtimes = ["3.6", "3.8"]
+available_runtimes = ["3.8"]
 
 # Python runtime used by default.
 default_runtime = "3.8"
 
 # Toolkits supported by this tool.
-available_toolkits = ["pyside2", "pyside6", "pyqt5", "wx", "null"]
+# PySide2 and PyQt5 are not (currently) available for EDM + Python 3.8, so we
+# don't support them here.
+available_toolkits = ["null", "pyqt6", "pyside6"]
 
 # Toolkit used by default.
 default_toolkit = "null"
 
 supported_combinations = {
-    "3.6": {"pyside2", "pyqt5", "wx", "null"},
-    "3.8": {"pyside6", "wx", "null"},
+    "3.8": {"null", "pyqt6", "pyside6"},
 }
 
 dependencies = {
     "apptools",
     "coverage",
     "enthought_sphinx_theme",
-    "flake8",
-    "flake8_ets",
-    "ipykernel",
     "pyface",
     "sphinx",
+    "sphinx_copybutton",
     "traits",
     "traitsui",
 }
 
 # Dependencies we install from PyPI
-pypi_dependencies = {"sphinx-copybutton"}
+pypi_dependencies = {
+    # style packages; install from PyPI to make sure that we're compatible
+    # with the style checks used in the check-style.yml workflow
+    "black~=23.0",
+    "flake8",
+    "flake8-ets",
+    "isort",
+}
 
 # Dependencies we install from source for cron tests
 # Order from packages with the most dependencies to one with the least
@@ -129,22 +135,12 @@ source_dependencies = [
 
 # Toolkit dependencies installed from EDM.
 toolkit_dependencies = {
-    "pyside2": {"pyside2"},
     "pyside6": {"pyside6"},
-    "pyqt5": {"pyqt5"},
-    # wxPython is not available in EDM; we'll need to pip install it
+    "pyqt6": {"pyqt6"},
 }
 
 runtime_dependencies = {}
 
-environment_vars = {
-    "pyside2": {"ETS_TOOLKIT": "qt", "QT_API": "pyside2"},
-    "pyside6": {"ETS_TOOLKIT": "qt", "QT_API": "pyside6"},
-    "pyqt5": {"ETS_TOOLKIT": "qt", "QT_API": "pyqt5"},
-    "wx": {"ETS_TOOLKIT": "wx"},
-    "null": {"ETS_TOOLKIT": "null"},
-}
-
 github_url_fmt = "git+http://github.com/enthought/{0}.git#egg={0}"
 
 # Options shared between different click commands.
@@ -196,6 +192,16 @@ def cli():
     pass
 
 
+# Subgroup for checking and fixing style
+
+
+@cli.group()
+def style():
+    """
+    Commands for checking style and applying style fixes.
+    """
+
+
 @cli.command()
 @edm_option
 @runtime_option
@@ -204,9 +210,7 @@ def cli():
 @editable_option
 @source_option
 def install(edm, runtime, toolkit, environment, editable, source):
-    """ Install project and dependencies into a clean EDM environment.
-
-    """
+    """Install project and dependencies into a clean EDM environment."""
     parameters = get_parameters(edm, runtime, toolkit, environment)
     packages = " ".join(
         dependencies
@@ -218,19 +222,6 @@ def install(edm, runtime, toolkit, environment, editable, source):
         "{edm} environments create {environment} --force --version={runtime}",
         "{edm} --config edm.yaml install -y -e {environment} " + packages,
     ]
-
-    # install wxPython with pip, because we don't have it in EDM
-    if toolkit == "wx":
-        if sys.platform == "linux":
-            # XXX This assumes Ubuntu 20.04, and targets CI.
-            commands.append(
-                "{edm} run -e {environment} -- python -m pip install -f https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-20.04/ wxPython"  # noqa: E501
-            )
-        else:
-            commands.append(
-                "{edm} run -e {environment} -- python -m pip install wxPython"
-            )
-
     commands.extend(
         [
             "{edm} run -e {environment} -- pip install " + dep
@@ -286,7 +277,7 @@ def install(edm, runtime, toolkit, environment, editable, source):
 @toolkit_option
 @environment_option
 def shell(edm, runtime, toolkit, environment):
-    """ Create a shell into the EDM development environment
+    """Create a shell into the EDM development environment
     (aka 'activate' it).
 
     """
@@ -297,17 +288,41 @@ def shell(edm, runtime, toolkit, environment):
     execute(commands, parameters)
 
 
-@cli.command()
+@style.command(name="check")
 @edm_option
 @runtime_option
 @toolkit_option
 @environment_option
-def flake8(edm, runtime, toolkit, environment):
-    """ Run a flake8 check in a given environment.
-
+def style_check(edm, runtime, toolkit, environment):
+    """
+    Run style checks.
     """
     parameters = get_parameters(edm, runtime, toolkit, environment)
-    commands = ["{edm} run -e {environment} -- python -m flake8 "]
+    commands = [
+        "{edm} run -e {environment} -- python -m black --check --diff .",
+        "{edm} run -e {environment} -- python -m isort --check --diff .",
+        "{edm} run -e {environment} -- python -m flake8 .",
+    ]
+    execute(commands, parameters)
+
+
+@style.command(name="fix")
+@edm_option
+@runtime_option
+@toolkit_option
+@environment_option
+def style_fix(edm, runtime, toolkit, environment):
+    """
+    Run style fixers.
+
+    This automatically fixes any black or isort failures, but it won't
+    automatically fix all flake8 errors.
+    """
+    parameters = get_parameters(edm, runtime, toolkit, environment)
+    commands = [
+        "{edm} run -e {environment} -- python -m black .",
+        "{edm} run -e {environment} -- python -m isort .",
+    ]
     execute(commands, parameters)
 
 
@@ -317,12 +332,9 @@ def flake8(edm, runtime, toolkit, environment):
 @toolkit_option
 @environment_option
 def test(edm, runtime, toolkit, environment):
-    """ Run the test suite in a given environment with the specified toolkit.
-
-    """
+    """Run the test suite in a given environment with the specified toolkit."""
     parameters = get_parameters(edm, runtime, toolkit, environment)
-    environ = environment_vars.get(toolkit, {}).copy()
-    environ["PYTHONUNBUFFERED"] = "1"
+    environ = dict(PYTHONUNBUFFERED="1")
     commands = [
         (
             "{edm} run -e {environment} -- python -W default -m "
@@ -347,12 +359,9 @@ def test(edm, runtime, toolkit, environment):
 @toolkit_option
 @environment_option
 def cleanup(edm, runtime, toolkit, environment):
-    """ Remove a development environment.
-
-    """
+    """Remove a development environment."""
     parameters = get_parameters(edm, runtime, toolkit, environment)
     commands = [
-        "{edm} run -e {environment} -- python setup.py clean",
         "{edm} environments remove {environment} --purge -y",
     ]
     click.echo("Cleaning up environment '{environment}'".format(**parameters))
@@ -365,9 +374,7 @@ def cleanup(edm, runtime, toolkit, environment):
 @runtime_option
 @toolkit_option
 def test_clean(edm, runtime, toolkit):
-    """ Run tests in a clean environment, cleaning up afterwards
-
-    """
+    """Run tests in a clean environment, cleaning up afterwards"""
     args = ["--toolkit={}".format(toolkit), "--runtime={}".format(runtime)]
     if edm is not None:
         args.append("--edm={}".format(edm))
@@ -386,9 +393,7 @@ def test_clean(edm, runtime, toolkit):
 @environment_option
 @editable_option
 def update(edm, runtime, toolkit, environment, editable):
-    """ Update/Reinstall package into environment.
-
-    """
+    """Update/Reinstall package into environment."""
     parameters = get_parameters(edm, runtime, toolkit, environment)
     if editable:
         install_cmd = (
@@ -409,9 +414,7 @@ def update(edm, runtime, toolkit, environment, editable):
 @cli.command()
 @edm_option
 def test_all(edm):
-    """ Run test_clean across all supported environment combinations.
-
-    """
+    """Run test_clean across all supported environment combinations."""
     failed_command = False
     for runtime, toolkits in supported_combinations.items():
         for toolkit in toolkits:
@@ -436,7 +439,7 @@ def test_all(edm):
 @toolkit_option
 @environment_option
 def docs(edm, runtime, toolkit, environment):
-    """ Build HTML documentation. """
+    """Build HTML documentation."""
 
     parameters = get_parameters(edm, runtime, toolkit, environment)
     parameters["docs_source"] = "docs/source"
@@ -446,29 +449,27 @@ def docs(edm, runtime, toolkit, environment):
 
     # Remove any previously autogenerated API documentation.
     doc_api_files = os.listdir(docs_source_api)
-    permanent = ['envisage.api.rst', 'templates']
-    previously_autogenerated = \
-        [file for file in doc_api_files if file not in permanent]
+    permanent = ["envisage.api.rst", "templates"]
+    previously_autogenerated = [
+        file for file in doc_api_files if file not in permanent
+    ]
     for file in previously_autogenerated:
         os.remove(os.path.join(docs_source_api, file))
 
-    apidoc_command = (
-        "{edm} run -e {environment} -- python -m sphinx.ext.apidoc --separate "
-        "--no-toc -o {docs_source_api} -t {templates_dir} envisage */tests"
-    )
     html_build_command = (
         "{edm} run -e {environment} -- python -m sphinx -b html "
         "{docs_source} {docs_build}"
     )
 
-    commands = [apidoc_command, html_build_command]
+    commands = [html_build_command]
     execute(commands, parameters)
 
 
 # Utility routines
 
+
 def get_parameters(edm, runtime, toolkit, environment):
-    """ Set up parameters dictionary for format() substitution """
+    """Set up parameters dictionary for format() substitution"""
 
     if edm is None:
         edm = locate_edm()
@@ -496,7 +497,7 @@ def get_parameters(edm, runtime, toolkit, environment):
 
 @contextmanager
 def do_in_tempdir(files=(), capture_files=()):
-    """ Create a temporary directory, cleaning up after done.
+    """Create a temporary directory, cleaning up after done.
 
     Creates the temporary directory, and changes into it.  On exit returns to
     original directory and removes temporary dir.
